@@ -1,9 +1,13 @@
 import requests
 import json
 import pathlib
-from typing import List
+from urllib.parse import urlencode
+from typing import List, Union
+from rich import print
 from rich.console import Console
 from ._typing import Group, Project
+from .errors import APIError
+
 
 BASE_URI = "https://gitedu.hesge.ch/api/v4"
 console = Console()
@@ -31,7 +35,7 @@ def get_owned_groups() -> List[Group]:
         'Private-Token': token
     }
 
-    with console.status("[bold green]Getting groups...") as status:
+    with console.status("[bold green]💾 Getting groups...") as status:
         response = requests.request("GET", url, headers=headers, data=payload).text
     response = json.loads(response)
 
@@ -61,7 +65,7 @@ def get_owned_projects(page=1):
         'Private-Token': token
     }
 
-    with console.status("[bold green]Getting projects...") as status:
+    with console.status("[bold green]💾 Getting projects...") as status:
         response = requests.request("GET", url, headers=headers, data=payload)
     response_json = json.loads(response.text)
 
@@ -81,3 +85,53 @@ def get_owned_projects(page=1):
         # Sort the project by full namespace for easier print later
         'list': sorted(p_list, key=lambda k: k.path_with_namespace)
     }
+
+
+def create_project(params:list) -> Union[Project, APIError]:
+    """Create a new project
+
+    Args:
+        params (list): Param list
+
+    Returns:
+        Project: Newly created project
+    """
+    if token == "":
+        print("No token as been register. Please do so using `setup --token <TOKEN_VALUE>.`")
+        return None
+
+    url = f'{BASE_URI}/projects?'
+
+    # Build url parameters
+    url_params = {}
+    for param in params:
+        if param["value"] is not None and param["value"] != "":
+            url_params[param["key"]] = param["value"]
+
+        # Special case for namespace check
+        if param["key"] == "namespace_id" and param["value"] == -1:
+            return APIError(message="Namespace not found")
+
+    url += urlencode(url_params)
+
+    payload = {}
+    headers = {
+        'Private-Token': token
+    }
+
+    with console.status("[bold green]🚀 Creating project...") as status:
+        response = requests.request("POST", url, headers=headers, data=payload)
+    response_json = json.loads(response.text)
+
+    return Project(
+        response_json['id'],
+        response_json['description'],
+        response_json['web_url'],
+        response_json['name'],
+        response_json['path_with_namespace'],
+        response_json['star_count'],
+        response_json['open_issues_count'],
+        response_json['namespace']['id'],
+        response_json['namespace']['name']
+    )
+        
\ No newline at end of file
