@@ -1,5 +1,5 @@
 import argparse
-from _typing import Command
+from ._typing import Command
 
 COMMANDS = [
     Command("create-app", "Create a new project."),
