@@ -12,12 +12,20 @@ def insert_subnamspace(parent: dict, subnamespace: Group):
     Returns:
         dict: Updated parent
     """
-    if parent['id'] == subnamespace.parent_id:
-        parent['children'].append(
-            {'id': subnamespace.id, 'name': subnamespace.name, 'url': subnamespace.web_url, 'children': [], 'projects': []})
+    if parent["id"] == subnamespace.parent_id:
+        parent["children"].append(
+            {
+                "id": subnamespace.id,
+                "name": subnamespace.name,
+                "full_path": subnamespace.full_path,
+                "url": subnamespace.web_url,
+                "children": [],
+                "projects": [],
+            }
+        )
         return parent
 
-    for _next_namespace in parent['children']:
+    for _next_namespace in parent["children"]:
         if isinstance(_next_namespace, dict):
             item = insert_subnamspace(_next_namespace, subnamespace)
             if item is not None:
@@ -34,11 +42,11 @@ def insert_project_in_namespace(namespaces: dict, project: Project):
     Returns:
         dict: Updated namespaces dict
     """
-    if namespaces['id'] == project.namespace['id']:
-        namespaces['projects'].append(project)
+    if namespaces["id"] == project.namespace["id"]:
+        namespaces["projects"].append(project)
         return namespaces
 
-    for _next_namespace in namespaces['children']:
+    for _next_namespace in namespaces["children"]:
         _next = insert_project_in_namespace(_next_namespace, project)
         if _next is not None:
             return _next
@@ -60,8 +68,16 @@ def create_namespace_tree(groups: List[Group], projects: List[Project]) -> list:
             for p in parent:
                 p = insert_subnamspace(p, group)
         else:
-            parent.append({'id': group.id, 'name': group.name, 'url': group.web_url,
-                          'children': [], 'projects': []})
+            parent.append(
+                {
+                    "id": group.id,
+                    "name": group.name,
+                    "full_path": group.full_path,
+                    "url": group.web_url,
+                    "children": [],
+                    "projects": [],
+                }
+            )
 
     tmp = projects.copy()
     for project in projects:
@@ -73,8 +89,15 @@ def create_namespace_tree(groups: List[Group], projects: List[Project]) -> list:
     # Now projects holds only personal projects (not the ones in groups)
     projects = tmp
     if len(projects) > 0:
-        parent.append({'id': projects[0].namespace['id'], 'name': 'Personal', 'url': f'https://gitedu.hesge.ch/users/{projects[0].namespace["name"]}/projects',
-                    'children': [], 'projects': []})
+        parent.append(
+            {
+                "id": projects[0].namespace["id"],
+                "name": "Personal",
+                "url": f'https://gitedu.hesge.ch/users/{projects[0].namespace["name"]}/projects',
+                "children": [],
+                "projects": [],
+            }
+        )
     for project in projects:
         insert_project_in_namespace(parent[-1], project)
 
